@@ -16,6 +16,7 @@ Including another URLconf
 from django.conf.urls import url
 from django.contrib import admin
 from django.urls import include
+from django.views.decorators.csrf import csrf_exempt
 from rest_framework import routers
 from django.urls import path
 from data.views.views import HardwareViewSet, AccessoryViewSet, CalibrationViewSet, ChannelViewSet, HubViewSet, \
@@ -70,8 +71,12 @@ urlpatterns = [
 
     # path('<str:room_name>/', views.room, name='room'),
     path('post/ajax/hub', HubViewSet.postHub, name="post_hub"),
+    path('hub/', csrf_exempt(HubViewSet.postHub)),
+    path('pipico/', csrf_exempt(HardwareViewSet.postHardware)),
 
     path('hub/<uuid:hub_id>/hardwares', HubViewSet.listHubHardware),
     path('hub/<uuid:hub_id>/channels', HubViewSet.listHubChannels),
     path('hub/<uuid:hub_id>/accessories', HubViewSet.listHubAccessories),
+    path('openhubapi/about', HubViewSet.about),
+
 ]
